@@ -1,4 +1,4 @@
-
+from datetime import datetime, timedelta
 from .objectJSON import ObjectJSON
 
 
@@ -33,7 +33,7 @@ class Boleto(ObjectJSON):
         self.TituloNumeroDocumento = str(titulo['numero_doc'])
         dataemissao = titulo['dataemi'].strftime('%d/%m/%Y')
         self.TituloDataEmissao = dataemissao
-        datavencimento = abs(dataemissao + titulo['prazo_vencimento'])
+        datavencimento = (titulo['dataemi'] + timedelta(days=titulo['prazo_vencimento']))
         datavencimento = datavencimento.strftime('%d/%m/%Y')
         self.TituloDataVencimento = datavencimento
         self.TituloAceite = None
