@@ -1,6 +1,6 @@
 class Outros(object):
 
-    def __init__(self, emi_boleto,categoria,postagem,cod_emissao,cod_distribuicao,outros_acrescimos,adicionais,instrucoes,parcela,variacao,codigo_ref,tipo_cobranca):
+    def __init__(self, outros):
         self.TituloEmissaoBoleto = None
         self.TituloCategoria = None
         self.TituloPostagemBoleto = None
